@@ -1,3 +1,3 @@
-from .intervals import (count_overlap, get_boolean_mask,
+from .intervals import (count_overlap, get_boolean_mask, global_intersect, unique_intersect,
                         get_pileup, intersect, sort_intervals, merge_intervals)
 from .similarity_measures import forbes, jaccard
